@@ -6,6 +6,7 @@ SPDX-License-Identifier: Apache-2.0
 import hashlib
 import json
 import uuid
+import logging
 from enum import Enum
 
 from graph_notebook.network.EventfulNetwork import EventfulNetwork
@@ -13,6 +14,9 @@ from gremlin_python.process.traversal import T
 from gremlin_python.structure.graph import Path, Vertex, Edge
 from networkx import MultiDiGraph
 
+logging.basicConfig()
+logger = logging.getLogger(__file__)
+
 T_LABEL = 'T.label'
 T_ID = 'T.id'
 
@@ -84,10 +88,12 @@ class GremlinNetwork(EventfulNetwork):
     You can find more details on this in our design doc for visualization here: https://quip-amazon.com/R1jbA8eECdDd
     """
 
-    def __init__(self, graph: MultiDiGraph = None, callbacks=None, label_max_length=DEFAULT_LABEL_MAX_LENGTH):
+    def __init__(self, graph: MultiDiGraph = None, callbacks=None, label_max_length=DEFAULT_LABEL_MAX_LENGTH,
+                 group_by_property=T_LABEL):
         if graph is None:
             graph = MultiDiGraph()
         self.label_max_length = label_max_length
+        self.group_by_property = group_by_property
         super().__init__(graph, callbacks)
 
     def add_results_with_pattern(self, results, pattern_list: list):
@@ -264,13 +270,15 @@ class GremlinNetwork(EventfulNetwork):
         if type(v) is Vertex:
             node_id = v.id
             title = v.label
+            group = v.label
             label = title if len(title) <= self.label_max_length else title[:self.label_max_length - 3] + '...'
-            data = {'label': label, 'title': title, 'properties': {'id': node_id, 'label': title}}
+            data = {'label': label, 'title': title, 'group': group, 'properties': {'id': node_id, 'label': title}}
         elif type(v) is dict:
             properties = {}
 
             title = ''
             label = ''
+            group = ''
             for k in v:
                 if str(k) == T_LABEL:
                     title = str(v[k])
@@ -278,6 +286,8 @@ class GremlinNetwork(EventfulNetwork):
                 elif str(k) == T_ID:
                     node_id = str(v[k])
                 properties[k] = v[k]
+                if str(k) == self.group_by_property:
+                    group = str(v[k])
 
             # handle when there is no id in a node. In this case, we will generate one which
             # is consistently regenerated so that duplicate dicts will be dedubed to the same vertex.
@@ -291,12 +301,13 @@ class GremlinNetwork(EventfulNetwork):
                     title += str(v[key])
                 label = title if len(title) <= self.label_max_length else title[:self.label_max_length - 3] + '...'
 
-            data = {'properties': properties, 'label': label, 'title': title}
+            data = {'properties': properties, 'label': label, 'title': title, 'group': group}
         else:
             node_id = str(v)
             title = str(v)
             label = title if len(title) <= self.label_max_length else title[:self.label_max_length - 3] + '...'
-            data = {'title': title, 'label': label}
+            data = {'title': title, 'label': label, 'group': ''}
+
         self.add_node(node_id, data)
 
     def add_path_edge(self, edge, from_id='', to_id='', data=None):
